@@ -8,25 +8,39 @@ def jprint(obj):
     text = json.dumps(obj, sort_keys=True, indent=1)
     print(text)
 
+def getTitleLang(Titledict):
+    langList = ["en", "ja", "ko", "zh"] # determine which langauge to use for title, prefers english, japanese, korean or chinese respectively
+    
+    if any([i in Titledict for i in langList]): # check if the title is available in aforementioned languages
+        for lang in Titledict:
+            if lang in langList:
+                title = Titledict[lang]
+                return title
+    else:
+        title = list(Titledict.values())[0]
+        return title
+
+
 def searchManga(title, doujin):
     
     if doujin:
         excluded_tags = []
-        included_tags = ["b13b2a48-c720-44a9-9c77-39c9979373fb"] # include doujins
+        included_tags = ["b13b2a48-c720-44a9-9c77-39c9979373fb", "7b2ce280-79ef-4c09-9b58-12b7c23a9b78"] # include doujins and fan colored
     else: 
-        excluded_tags = ["b13b2a48-c720-44a9-9c77-39c9979373fb", "320831a8-4026-470b-94f6-8353740e6f04"] # exclude both colored and doujins
+        excluded_tags = ["b13b2a48-c720-44a9-9c77-39c9979373fb", "7b2ce280-79ef-4c09-9b58-12b7c23a9b78"] # exclude both colored and doujins
         included_tags = []
 
     params = {
         "title": title,
         "order[relevance]": "desc",
         "excludedTags[]": excluded_tags,
-        "includedTags[]": included_tags
+        "includedTags[]": included_tags,
+        "includedTagsMode": "OR"
     }
     response = requests.get("https://api.mangadex.org/manga", params=params).json()
     
     if response["total"] != 0:
-        click.echo(response['data'][0]['attributes']['title']['en'])
+        click.echo(getTitleLang(response['data'][0]['attributes']['title']))
     else:
         click.secho("\nCouldn't find any results", fg='red', reset=True)
         exit(404)
@@ -37,9 +51,9 @@ def searchManga(title, doujin):
 def getInfo(response, cover, details):
     data = response['data'][0]
     manga_id = data['id']
-    title = data['attributes']['title']['en']
-    author = getAuthor(data['relationships'][0]['id'].strip('"'))
-    artist = getArtist(data['relationships'][1]['id'].strip('"'))
+    title = getTitleLang(data['attributes']['title'])
+    author = getAuthor(data['relationships'][0]['id'])
+    artist = getArtist(data['relationships'][1]['id'])
     description = str(data['attributes']['description']['en']).split("[", 1)[0].rstrip().split("\\", 1)[0].rstrip().split("---", 1)[0].rstrip().split("**", 1)[0].rstrip()
     demographic = data['attributes']['publicationDemographic']
     country_of_origin = data['type']
@@ -57,10 +71,11 @@ def getInfo(response, cover, details):
     status = data['attributes']['status']
 
     click.echo("\nDETAILS:\n")
-    click.echo("Title: " + title +"\nAuthor: " + author +"\nArtist: " + artist + "\nDescription: " + description + "\n\nGenres: \n" + str(tags) + "\n\nStatus: " + status.title())
-    click.echo("\n\nId: " + manga_id + "\n")
+    click.echo(f"Title: {title} \nAuthor: {author} \nArtist: {artist} \nDescription: {description} \n\nGenres: \n{tags} \n\nStatus: {status.title()}")
+    click.echo(f"\n\nId: {manga_id} \n")
     
     if cover:
+        click.echo("\nCOVERS:\n")
         getCover(manga_id, cover)
 
     if details:
@@ -96,7 +111,7 @@ def getCover(id, cover):
     }
     response = requests.get("https://api.mangadex.org/cover", params=params).json()
     cwd = os.getcwd()
-    cover_folder = os.path.join(cwd, "mangadex_covers")
+    cover_folder = os.path.join(cwd, "volume_covers")
     if cover == 'all':
         if os.path.isdir(cover_folder) == False:
             os.mkdir(cover_folder)
@@ -107,7 +122,7 @@ def getCover(id, cover):
         cover_filename = i['attributes']['fileName']
         volume = i['attributes']['volume']
         if volume != None:
-            click.echo("Volume " + volume + ": " + cover_filename)
+            click.echo(f"Volume {volume}: {cover_filename}")
             saveCover(volume, cover_filename, id, cover_folder)
             if cover == 'first' or cover == 'last':
                 break
@@ -140,5 +155,5 @@ def saveDetails(title, author, artist, description, tags, status):
     }
     
     with open('details.json', 'w') as json_file:
-        json.dump(details_dict, json_file, indent=1, ensure_ascii=False)
+        json.dump(details_dict, json_file, indent=2, ensure_ascii=False)
     
\ No newline at end of file
